@@ -1,6 +1,5 @@
 from __future__ import annotations
 
-import asyncio
 from typing import TYPE_CHECKING, Optional
 
 import strawberry
@@ -11,13 +10,8 @@ if TYPE_CHECKING:
 
 
 async def mutate_exec(info: Info) -> bool:
-
     nextline: Nextline = info.context["nextline"]
-
-    async def wait():
-        await nextline.run()
-
-    asyncio.create_task(wait())
+    await nextline.run()
     return True
 
 
@@ -27,11 +21,11 @@ async def mutate_reset(info: Info, statement: Optional[str] = None):
     return True
 
 
-def mutate_send_pdb_command(
+async def mutate_send_pdb_command(
     info: Info, command: str, prompt_no: int, trace_no: int
 ) -> bool:
     nextline: Nextline = info.context["nextline"]
-    nextline.send_pdb_command(command, prompt_no, trace_no)
+    await nextline.send_pdb_command(command, prompt_no, trace_no)
     return True
 
 
